businesstemplates
=================

.. image:: https://img.shields.io/pypi/v/businesstemplates.svg
   :target: https://pypi.python.org/pypi/businesstemplates
   :alt: PyPI Version Info
.. image:: https://img.shields.io/pypi/pyversions/businesstemplates.svg
   :target: https://pypi.python.org/pypi/businesstemplates
   :alt: PyPI Supported Python Versions

An efficient command line tool to create resumes and business cards on the go!

Notable Features
----------------

- Modern pythonic syntax.
- Easy to run scripts.
- Covers all important information.
- Lightweight module.

Installing
----------

**"Python 3.7" or higher is required to install this module.**

Installing this module is quite simple,

.. code:: sh

	# Linux/MacOS
	python3 -m pip install -U businesstemplates

	# Windows
	py -3 -m pip install -U businesstemplates

Other Required Packages
~~~~~~~~~~~~~~~~~~~~~~~~

* `python-docx <https://github.com/python-openxml/python-docx>`__
* `pathlib`

How to run?
-----------

Resume Generator
~~~~~~~~~~~~~~~~

Now you can design your own impressive resume

Open your favourite terminal and enter this

.. code:: sh

	resume_generator

Enter the information through the inputs and you're done!

Business Card Generator
~~~~~~~~~~~~~~~~~~~~~~~

Design your sparkling business card in just under a minute.

Open your favourite terminal and enter this

.. code:: sh
	business_card_generator

Enter the information through the inputs and you're done!

